==> XamPy-0.1.2.tar.gz: XamPy-0.1.2/README.md <==
# XamPy
## Links
- [Code of Conduct](https://github.com/XamNalpak/xampy/blob/main/CODE-OF-CONDUCT.md)
- [Contributing](https://github.com/XamNalpak/xampy/blob/main/CONTRIBUTING.md)
- [Issues](https://github.com/XamNalpak/xampy/issues)
- [License](https://github.com/XamNalpak/xampy/blob/main/LICENSE)


# _Information_


XamPy is a Data Science Package written in Python. 
## Features

- Simplifying the process of analyzing data
- User-Friendly command based sripting package

## Packages Used

XamPy uses a number of open source projects to work properly:

- Pandas - Data manipulation tool for python
- Numpy - awesome tool for matrix/array mathmatics
- MatPlotLib - tool for graphing in python

# Installation
```
pip install xampy
or
pip3 install xampy
```
# Example Use cases
## Reading in data from file path
```
import xampy as xp
path = 'C:\Users\User\Documents\Data\data.csv'

# using makeData() to read in data
data = xp.makeData(path)

# quick statistics and summary of the data at hand
xp.showInfo(data)

# removing white space from column names and insert an underscore
data = xp.renameCols(data,' ','_')

# splitting the data into numerical and nonnumerical sections

numerical,categorical = xp.dataTypeSplit(data)


# Counting nulls in the dataframe, prints the number of missing vals in the DF
xp.CountMissing(data)

# example column money (float) has missing values
data = xp.meanFill(data,'money')

# example column Gender (Binary or text) has missing values
data = xp.modeFill(data,'Gender')

```
 - eq=equal
 - gte=greater than equal to
 - lte=less than equal to
 - lt = less than
 - gt = greater than

#### FOR STRINGS WE USE 'eq', for any numerical data we can use any comparrison #operator
```
males = xp.SubSetDf(data,'Gender','Male','eq')
females = xp.SubSetDf(data,'Gender','Female','eq')
```
# Contributors and Contributions
IF YOU ARE A CONTRIBUTOR AND ARE NOT LISTED PLEASE EMAIL [Max Paul](mailto:maxkpaul21@gmail.com) or submit a new issue.

 - Max Paul 
   - Lead Contributor/Founder
   - Bachelor Of Science In Data Science from Bryant Unversity.
   - Software engineer by day for TJX.


## License

MIT

**Free Software, Hell Yeah!**

==> XamPy-0.1.3.3.tar.gz: XamPy-0.1.3.3/README.md <==
# XamPy
## Links
- [Code of Conduct](https://github.com/XamNalpak/xampy/blob/main/CODE-OF-CONDUCT.md)
- [Contributing](https://github.com/XamNalpak/xampy/blob/main/CONTRIBUTING.md)
- [Issues](https://github.com/XamNalpak/xampy/issues)
- [License](https://github.com/XamNalpak/xampy/blob/main/LICENSE)
- [Current Functions](https://github.com/XamNalpak/xampy/blob/main/FUNCTIONS.md)



# _Information_


XamPy is a Data Science Package written in Python. 
## Features

- Simplifying the process of analyzing data
- User-Friendly command based sripting package

## Packages Used

XamPy uses a number of open source projects to work properly:

- Pandas - Data manipulation tool for python
- Numpy - awesome tool for matrix/array mathmatics
- MatPlotLib - tool for graphing in python
- vaderSenitment - tool for senitment anaylsis of social media
- nltk - natural language processing and text mining
- textblob - sentiment analysis on a larger size of text
- datetime for date manipulation

# Installation
```
pip install xampy
or
pip3 install xampy
```

# Contributors and Contributions
IF YOU ARE A CONTRIBUTOR AND ARE NOT LISTED PLEASE EMAIL [Max Paul](mailto:maxkpaul21@gmail.com) or submit a new issue.

 - Max Paul 
   - Lead Contributor/Founder
   - Bachelor Of Science In Data Science from Bryant Unversity.
   - Software engineer by day for TJX.

# Example Use

```
import xampy as xp

# reading data and showing information
data = xp.makeData('topcsv.csv')
xp.showInfo(data)

# dropping all the rows that contain nulls get dropped
data = xp.dropnaDim(data,'row')

#counting missing data to show all values have been dropped
xp.countMissing(data)

#conducting sentiment analysis on the text data
data = xp.socialSentiment(data,'Content')

#showing the new dataframe
data.head(10)





```

## License

MIT

**Free Software, Hell Yeah!**
